Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1490)

Unified Diff: chrome/browser/gpu_process_host_ui_shim.h

Issue 6793054: Moved code that runs in both the browser and GPU process from content/gpu to content/common/gpu. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gpu_data_manager.h ('k') | chrome/browser/gpu_process_host_ui_shim.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/gpu_process_host_ui_shim.h
===================================================================
--- chrome/browser/gpu_process_host_ui_shim.h (revision 80399)
+++ chrome/browser/gpu_process_host_ui_shim.h (working copy)
@@ -21,10 +21,10 @@
#include "base/memory/singleton.h"
#include "base/process.h"
#include "base/threading/non_thread_safe.h"
+#include "content/common/gpu/gpu_channel_manager.h"
+#include "content/common/gpu/gpu_info.h"
#include "content/common/gpu_feature_flags.h"
-#include "content/common/gpu_info.h"
#include "content/common/message_router.h"
-#include "content/gpu/gpu_render_thread.h"
#include "ui/gfx/native_widget_types.h"
namespace gfx {
@@ -207,9 +207,9 @@
ViewSurfaceMap acquired_surfaces_;
// In single process and in process GPU mode, this references the
- // GpuRenderThread or null otherwise. It must be called and deleted on the GPU
- // thread.
- GpuRenderThread* gpu_render_thread_;
+ // GpuChannelManager or null otherwise. It must be called and deleted on the
+ // GPU thread.
+ GpuChannelManager* gpu_channel_manager_;
// This is likewise single process / in process GPU specific. This is a Sender
// implementation that forwards IPC messages to this UI shim on the UI thread.
« no previous file with comments | « chrome/browser/gpu_data_manager.h ('k') | chrome/browser/gpu_process_host_ui_shim.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698